/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIDOMTreeWalker.idl"

interface nsIDOMNode;

[scriptable, uuid(91FCA0E9-99D6-406b-9D78-4C96F11E9EE4)]
interface inIDeepTreeWalker : nsIDOMTreeWalker
{
  attribute boolean showAnonymousContent;
  attribute boolean showSubDocuments;
  
  void init(in nsIDOMNode aRoot, in unsigned long aWhatToShow);
};

