/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


#include "domstubs.idl"

interface nsIDOMGeoPositionError;

[scriptable, function, uuid(7D9B09D9-4843-43EB-A7A7-67F7DDA6B3C4)]
interface nsIDOMGeoPositionErrorCallback : nsISupports {
  void handleEvent(in nsIDOMGeoPositionError positionError);
};
