/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

%{C++

#define NS_READCONFIG_CID\
  { 0xba5bc4c6,\
    0x1dd1, \
    0x11b2, \
    { 0xbb, 0x89, 0xb8, 0x44, 0xc6, 0xec, 0x03, 0x39 }\
  }
 
#define NS_READCONFIG_CONTRACTID \
  "@mozilla.org/readconfig;1" 

%}

[uuid (ba5bc4c6-1dd1-11b2-bb89-b844c6ec0339)]
interface nsIReadConfig : nsISupports {
};
